@@ -10,7 +10,7 @@ use parent 'Type::Tiny::Signatures';
 
 our @DEFAULTS = @Type::Tiny::Signatures::DEFAULTS = 'Data::Object::Library';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 1;
 
@@ -26,7 +26,7 @@ Data::Object::Signatures - Data::Object Method/Function Signatures for Perl 5
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -34,9 +34,11 @@ version 0.03
 
 =head1 DESCRIPTION
 
-Data::Object::Signatures is a subclass of L<Type::Tiny::Signatures> providing
+Data::Object::Signatures is a subclass of Type::Tiny::Signatures providing
 method and function signatures supporting all the type constraints provided by
-L<Data::Object::Library>.
+L<Data::Object::Library>. B<NOTE:> This distribution is now available as part
+of the L<Data::Object> core distribution. Please be sure to depend on
+Data::Object directly (version 0.50 or later).
 
 =head1 AUTHOR
 
